summaryrefslogtreecommitdiffstats
path: root/src/BiomeDef.h
diff options
context:
space:
mode:
authorTycho <work.tycho+git@gmail.com>2014-02-03 21:26:17 +0100
committerTycho <work.tycho+git@gmail.com>2014-02-03 21:26:17 +0100
commit80807eec2cc1c497c4766a0c7cddb9c3ddc29e45 (patch)
tree4655d0f74ce54797b73e4863c2df30134ea74763 /src/BiomeDef.h
parentMerge pull request #623 from mc-server/tnt (diff)
downloadcuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.tar
cuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.tar.gz
cuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.tar.bz2
cuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.tar.lz
cuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.tar.xz
cuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.tar.zst
cuberite-80807eec2cc1c497c4766a0c7cddb9c3ddc29e45.zip
Diffstat (limited to 'src/BiomeDef.h')
-rw-r--r--src/BiomeDef.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/BiomeDef.h b/src/BiomeDef.h
index df1e387f0..f015dd836 100644
--- a/src/BiomeDef.h
+++ b/src/BiomeDef.h
@@ -20,6 +20,9 @@ BiomeIDs over 255 are used by MCServer internally and are translated to MC biome
*/
enum EMCSBiome
{
+ biInvalidBiome = -1,
+
+ biFirstBiome = 0,
biOcean = 0,
biPlains = 1,
biDesert = 2,
@@ -74,6 +77,7 @@ enum EMCSBiome
biVariant = 128,
// Release 1.7 biome variants:
+ biFirstVarientBiome = 129,
biSunflowerPlains = 129,
biDesertM = 130,
biExtremeHillsM = 131,
@@ -95,9 +99,12 @@ enum EMCSBiome
biMesaBryce = 165,
biMesaPlateauFM = 166,
biMesaPlateauM = 167,
+ // Automatically capture the maximum consecutive biome value into biVarientMaxBiome:
+ biNumVarientBiomes, // True number of biomes, since they are zero-based
+ biMaxVarientBiome = biNumVarientBiomes - 1, // The maximum biome value
} ;
/// Translates a biome string to biome enum. Takes either a number or a biome alias (built-in). Returns -1 on failure.
extern EMCSBiome StringToBiome(const AString & a_BiomeString);
/// Returns true if the biome has no downfall - deserts and savannas
@@ -95,9 +99,12 @@ enum EMCSBiome
} ;
-/// Translates a biome string to biome enum. Takes either a number or a biome alias (built-in). Returns -1 on failure.
+/// Translates a biome string to biome enum. Takes either a number or a biome alias (built-in). Returns biInvalidBiome on failure.
extern EMCSBiome StringToBiome(const AString & a_BiomeString);
/// Returns true if the biome has no downfall - deserts and savannas